@@ -3,7 +3,7 @@ use std::{
     task::{Context, Poll},
 };
 
-use futures::{channel::mpsc, ready, Stream, StreamExt};
+use futures::{channel::mpsc, future, ready, Stream, StreamExt, TryStreamExt};
 use pin_project_lite::pin_project;
 
 use crate::{errors::CondowError, streams::ChunkStreamItem};
@@ -158,6 +158,14 @@ impl ChunkStream {
     pub fn try_into_part_stream(self) -> Result<OrderedChunkStream, CondowError> {
         OrderedChunkStream::try_from(self)
     }
+
+    /// Counts the number of bytes downloaded
+    ///
+    /// Provided mainly for testing.
+    pub async fn count_bytes(self) -> Result<u64, CondowError> {
+        self.try_fold(0u64, |acc, chunk| future::ok(acc + chunk.len() as u64))
+            .await
+    }
 }
 
 async fn stream_into_vec_with_unknown_size(
